netapp_ontap.models.nfs_service_protocol_v3_features API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_protocol_v3_features`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceProtocolV3FeaturesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceProtocolV3Features object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `connection_drop: bool GET POST PATCH`

    Specifies whether the dropping of a connection when an NFSv3 request is dropped is enabled.

  `ejukebox_enabled: bool GET POST PATCH`

    Specifies whether NFSv3 EJUKEBOX error is enabled.

  `fsid_change: bool GET POST PATCH`

    Specifies whether the change in FSID as NFSv3 clients traverse filesystems should be shown.

  `hide_snapshot_enabled: bool GET POST PATCH`

    Specifies whether hiding a snapshot directory under a NFSv3 mount point is enabled.

  `mount_daemon_port: Size GET POST PATCH`

    Specifies which port the NFS mount daemon (mountd) uses.

  `mount_root_only: bool GET POST PATCH`

    Specifies whether the SVM allows MOUNT protocol calls only from privileged ports (port numbers less than 1024).

  `network_lock_manager_port: Size GET POST PATCH`

    Specifies which port the Network lock manager uses.

  `network_status_monitor_port: Size GET POST PATCH`

    Specifies which port the Network status monitor port uses.

  `rquota_daemon_port: Size GET POST PATCH`

    Specifies which port the NFS quota daemon port uses.